@@ -1,9 +1,21 @@
-from collections import namedtuple
-import rxsci.operators as rsops
+import rxsci as rs
 
 
 def fill_none(value):
     '''Replaces None values with value
+
+    .. marble::
+        :alt: fill_none
+
+        -0----none-2----1-----|
+        [    fill_none(42)    ]
+        -0----42---4----1-----|
+
+    Args:
+        value: The value used to replace None values.
+
+    Returns:
+        An observable where None items are replaced with value.
     '''
 
     def __fill_none(i):
@@ -23,7 +35,7 @@ def fill_none(value):
 
     def _fill_none(source):
         return source.pipe(
-            rsops.map(__fill_none),
+            rs.ops.map(__fill_none),
         )
 
     return _fill_none
