@@ -1,7 +1,6 @@
 import math
 import rx.operators as ops
 import rxsci as rs
-import rxsci.operators as rsops
 
 
 def stddev(key_mapper=lambda i: i, reduce=False):
@@ -24,7 +23,7 @@ def stddev(key_mapper=lambda i: i, reduce=False):
     def _stddev(source):
         return source.pipe(
             rs.math.formal.variance(key_mapper, reduce=reduce),
-            rsops.map(lambda i: math.sqrt(i) if i is not None else None),
+            rs.ops.map(lambda i: math.sqrt(i) if i is not None else None),
         )
 
     return _stddev
