@@ -1,10 +1,17 @@
 import rx
-import rxsci.operators as rsops
+import rxsci as rs
 
 
 def max(key_mapper=lambda i: i, reduce=False):
     '''Returns the maximum value emitted in the source observable.
 
+    .. marble::
+        :alt: max
+
+        -0-1-4-2-3-8-2-6---|
+        [       max()      ]
+        -0-1-4-----8-------|
+
     Args:
         key_mapper: [Optional] a function called on each item before computing
             the max.
@@ -22,4 +29,4 @@ def max(key_mapper=lambda i: i, reduce=False):
 
         return acc
 
-    return rsops.scan(accumulate, None, reduce=reduce)
+    return rs.ops.scan(accumulate, None, reduce=reduce)
