@@ -1,10 +1,17 @@
 import rx
-import rxsci.operators as rsops
+import rxsci as rs
 
 
 def min(key_mapper=lambda i: i, reduce=False):
     '''Returns the minimum value emitted in the source observable.
 
+    .. marble::
+        :alt: min
+
+        -9-7-8-2-3-8-2-6---|
+        [       min()      ]
+        -9-7---2-----------|
+
     Args:
         key_mapper: [Optional] a function called on each item before computing
             the min.
@@ -22,4 +29,4 @@ def min(key_mapper=lambda i: i, reduce=False):
 
         return acc
 
-    return rsops.scan(accumulate, None, reduce=reduce)
+    return rs.ops.scan(accumulate, None, reduce=reduce)
