@@ -1,6 +1,8 @@
 from .assert_ import assert_, assert_1
 from .count import count
 from .distinct import distinct
+from .distinct_until_changed import distinct_until_changed
+from .do_action import do_action
 from .filter import filter
 from .first import first
 from .group_by import group_by
@@ -8,6 +10,7 @@ from .last import last
 from .map import map
 from .multiplex import multiplex, demux_mux_observable
 from .on_subscribe import on_subscribe
+from .pandas import to_pandas
 from .progress import progress
 from .starmap import starmap
 from .start_with import start_with
