@@ -1,7 +1,6 @@
 import rx
 import rx.operators as ops
 import rxsci as rs
-import rxsci.operators as rsops
 
 
 def test_last_mux():
@@ -24,7 +23,7 @@ def test_last_mux():
 
     rx.from_(source).pipe(
         rs.cast_as_mux_observable(),
-        rsops.last(),
+        rs.ops.last(),
     ).subscribe(
         on_next=actual_result.append,
         on_completed=on_completed,
@@ -43,3 +42,34 @@ def test_last_mux():
     ]
 
 
+def test_last_mux_empty():
+    source = [
+        rs.OnCreateMux((1,)),
+        rs.OnCreateMux((2,)),
+        rs.OnCompletedMux((1,)),
+        rs.OnCompletedMux((2,)),
+    ]
+    actual_error = []
+    actual_completed = []
+    actual_result = []
+
+    def on_completed():
+        actual_completed.append(True)
+
+    rx.from_(source).pipe(
+        rs.cast_as_mux_observable(),
+        rs.ops.last(),
+    ).subscribe(
+        on_next=actual_result.append,
+        on_completed=on_completed,
+        on_error=actual_error.append,
+    )
+
+    assert actual_error == []
+    assert actual_completed == [True]
+    assert actual_result == [
+        rs.OnCreateMux((1,)),
+        rs.OnCreateMux((2,)),
+        rs.OnCompletedMux((1,)),
+        rs.OnCompletedMux((2,)),
+    ]
